==> haskell-unix-compat-0.7.2-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unix-compat
version:              0.7.2
visibility:           public
id:                   unix-compat-0.7.2-3S8nQVag41zGjHM5MpRJPG
key:                  unix-compat-0.7.2-3S8nQVag41zGjHM5MpRJPG
license:              BSD-3-Clause
maintainer:           https://github.com/haskell-pkg-janitors
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             https://github.com/haskell-pkg-janitors/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  92e90effa71c41105dd38bb00b97a0ec
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Process
    System.PosixCompat.Temp System.PosixCompat.Time
    System.PosixCompat.Types System.PosixCompat.Unistd

import-dirs:          /usr/lib/ghc-9.2.8/site-local/unix-compat-0.7.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unix-compat-0.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.7.2-3S8nQVag41zGjHM5MpRJPG
include-dirs:         /usr/lib/ghc-9.2.8/site-local/unix-compat-0.7.2/include
includes:             HsUnixCompat.h
depends:              base-4.16.4.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.7.3-28.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-compat
version:              0.7.3
visibility:           public
id:                   unix-compat-0.7.3-CU7UWjjGR4i9UIe1hCdWTL
key:                  unix-compat-0.7.3-CU7UWjjGR4i9UIe1hCdWTL
license:              BSD-3-Clause
maintainer:           https://github.com/haskell-pkg-janitors
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             https://github.com/haskell-pkg-janitors/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  3dd73ee00b30360feea042a1cc55d9b1
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Process
    System.PosixCompat.Temp System.PosixCompat.Time
    System.PosixCompat.Types System.PosixCompat.Unistd

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.7.3-CU7UWjjGR4i9UIe1hCdWTL
include-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.3/include
includes:             HsUnixCompat.h
depends:              base-4.17.2.1 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
